"""Shop request models for API communication."""

from shop_system_models.shop_api.shop.request.orders import (
    AddressModel,
    BookingOrderModel,
    Coordinates,
    CreateOrderModel,
    DeliveryTypeModel,
    ExtraField,
    ExtraFieldPayload,
    OrderDeliveryTypeModel,
    OrderModel,
)
